@@ -7,6 +7,7 @@ from openpyxl import load_workbook
 
 
 def test_dump_customers(fs, mocked_responses, mocked_customer, mocked_reseller):
+
     warnings.filterwarnings("ignore", category=UserWarning)
     mocked_responses.add(
         method='GET',
@@ -22,9 +23,12 @@ def test_dump_customers(fs, mocked_responses, mocked_customer, mocked_reseller):
         api_key='ApiKey XXX',
         silent=True,
         account_id='PA-1234',
-        output_file='/Customers.xlsx'
+        output_file=f'{fs.root_path}/Customers.xlsx'
+    )
+    customers_wb = load_workbook(
+        output_file,
+        data_only=True,
     )
-    customers_wb = load_workbook(output_file)
     ws = customers_wb['Customers']
     assert len(ws['A']) == 3
     assert ws['A2'].value == mocked_customer['id']
